#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_INBTRUE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_INBTRUE_HPP_INCLUDED

#include <nt2/reduction/include/functions/scalar/inbtrue.hpp>

#endif
